#!/bin/bash

# F5YG Feb 13th, 2016

# wget
WGET=$(command -v wget)
if [ -z $WGET ]; then
  printf "%s\n" "wget is missing. Please install it"
  exit 1
fi

# Default home location
DEFLONG=-1.9289
DEFLAT=49.3725
DEFLOC=Le_Vauroux

# Get date now
function now {
  printf "%s" $(date "+%Y-%m-%d")
}

echo
echo " ****************************************************************************"
echo " * Rise, transit and set of the Sun at a given epoch for a given geographic *"
echo " *           location using the IMCCE Miriade Ephemeris Generator           *"
echo " *            More info: http://vo.imcce.fr/webservices/miriade/            *"
echo " ****************************************************************************"
echo
echo "Home location is: $DEFLOC"
echo

# enter variables
echo -n "Enter start date (format yyyy-mm-dd) [now]: "
read EP
[ -z $EP ] && EP=$(now)

echo -n "Enter the number of date of computation (>= 1 and < 731) [1]: "
read NBD
[ -z $NBD ] && NBD=1

echo -n "Enter longitude (negative toward East) [$DEFLONG]: "
read LO
[ -z $LO ] && LONG=$DEFLONG || LONG=$LO

echo -n "Enter latitude (negative toward South) [$DEFLAT]: "
read LA
[ -z $LA ] && LAT=$DEFLAT|| LAT=$LA

printf "\n%s %d %s %s\n" "Computing ephemeris for" "$NBD" "days beginning on" "$EP"
printf "%s %s %s %s %s\n" "Location: longitude" "$LONG" "deg., latitude" "$LAT" "deg."

# Miriade rts URL
url="http://vo.imcce.fr/webservices/miriade/rts_query.php?"

# Epoch
epoch="-ep=$EP&"
# Body = Sun
body="-body=11&"
# Number of date
nbdate="-nbd=$NBD&"
# Longitude
long="-long=$LONG&"
# Latitude
lat="-lat=$LAT&"
# Timezone = UTC
tz="-tz=0&"
# Mime type of the output (votable, html, text)
mime="-mime=text&"
# Number of decimals of output data
extrap="-extrap=0&"

# Miriade arguments
miriade_args=${epoch}${body}${nbdate}${long}${lat}${tz}${mime}${extrap}

# Call Miriade rts service
$WGET -o rts.log -O ephemeris.dat "${url}${miriade_args}"

printf "\n%s\n%s\n" "done" "Data saved in file ephemeris.dat"
